Changelog for Falcon 3.0.0
==========================

Changes to Supported Platforms
------------------------------

- Python 3.8 is now fully supported.
- Python 3.6+ is only required when using the new ASGI interface. WSGI is still
  supported on Python 3.5+.
- Python 3.5 support is deprecated and may be removed in the next major release.
- Python 3.4 is no longer supported.
- The Falcon 2.x series was the last to support Python language version 2. As a
  result, support for CPython 2.7 and PyPy2.7 was removed in Falcon 3.0.

.. towncrier release notes start

Contributors to this Release
----------------------------

Many thanks to all of our talented and stylish contributors for this release!

- `BigBlueHat <https://github.com/BigBlueHat>`_
- `CaselIT <https://github.com/CaselIT>`_
- `Ciemaar <https://github.com/Ciemaar>`_
- `Coykto <https://github.com/Coykto>`_
- `cozyDoomer <https://github.com/cozyDoomer>`_
- `cravindra <https://github.com/cravindra>`_
- `csojinb <https://github.com/csojinb>`_
- `edmondb <https://github.com/edmondb>`_
- `jmvrbanac <https://github.com/jmvrbanac>`_
- `karlhigley <https://github.com/karlhigley>`_
- `kemingy <https://github.com/kemingy>`_
- `kgriffs <https://github.com/kgriffs>`_
- `mattdonders <https://github.com/mattdonders>`_
- `mikeyusko <https://github.com/mikeyusko>`_
- `minrock <https://github.com/minrock>`_
- `mosi-kha <https://github.com/mosi-kha>`_
- `nZac <https://github.com/nZac>`_
- `nagaabhinaya <https://github.com/nagaabhinaya>`_
- `pbjr23 <https://github.com/pbjr23>`_
- `rmyers <https://github.com/rmyers>`_
- `safaozturk93 <https://github.com/safaozturk93>`_
- `screamingskulls <https://github.com/screamingskulls>`_
- `seanharrison <https://github.com/seanharrison>`_
- `timgates42 <https://github.com/timgates42>`_
- `vytas7 <https://github.com/vytas7>`_
- `waghanza <https://github.com/waghanza>`_
